==> dcoupon_sdk_flutter_package-1.1.3.tar.gz: lib/src/data/helpers/users_api_helper.dart <==
import 'package:dcoupon_sdk_flutter_package/src/config_reader.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/helpers/authorization_helper.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/constants.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/enum_helper.dart';

const String VERSION = "v1";

const Map<String, String> URLS_BY_ENVIRONMENT = {
  'local': 'http://localhost:3000/',
  'test': 'https://testapi.dcoupon.com/users/',
  'dev': 'https://services-dev.dcoupon.com/users/',
  'dcoupon.eu': 'https://services.dcoupon.eu/users/',
  'dcoupon.com': 'https://services.dcoupon.com/users/'
};

class UsersApiHelper {
  static Map<String, dynamic> buildHeaders({
    bool userAuthentication = true,
  }) {
    var headers = <String, dynamic>{};

    final currentDateFormatted = AuthorizationHelper.getCurrentDateFormatted();
    headers[Constants.HEADER_AUTH_METHOD] =
        EnumHelper.enumToString(AuthMethod.SIGNATURE);
    headers[Constants.HEADER_AUTH_TIMESTAMP] = currentDateFormatted;
    headers[Constants.HEADER_AUTH_APIKEY] = ConfigReader.clientApiToken;
    headers[Constants.HEADER_AUTH_SIGNATURE] =
        AuthorizationHelper.getAuthSignature(currentDateFormatted);
    if (userAuthentication) {
      headers[Constants.HEADER_USER_JWT] = ConfigReader.userJwt;
    }

    return headers;
  }

  static String getUserDataUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain] + VERSION + "/data";
  }

  static String updateUserDataUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain] + VERSION + "/data";
  }

  static String getLoyaltyAffiliatesUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain] +
        VERSION +
        "/loyalty/affiliates/" +
        ConfigReader.clientCountry;
  }

  static String getUserLoyaltyCardsUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain] +
        VERSION +
        "/loyalty/cards";
  }

  static String addOrUpdateLoyaltyCardUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain] +
        VERSION +
        "/loyalty/card";
  }

  static String deleteLoyaltyCardUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain] +
        VERSION +
        "/loyalty/card";
  }

  static String getUserRedemptionSummaryUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain] +
        VERSION +
        "/redemption/summary";
  }

  static String getUserRedemptionHistoryUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain] +
        VERSION +
        "/redemption/history";
  }

  static String getRedemptionDetail(String redemptionId) {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain] +
        VERSION +
        "/redemption/detail/" +
        redemptionId;
  }
}

==> dcoupon_sdk_flutter_package-5.1.0.tar.gz: lib/src/data/helpers/users_api_helper.dart <==
import 'package:dcoupon_sdk_flutter_package/src/config_reader.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/helpers/authorization_helper.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/constants.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/enum_helper.dart';

const String VERSION = "v3";

const Map<String, String> URLS_BY_ENVIRONMENT = {
  'local': 'http://localhost:3000/',
  'test': 'https://testapi.dcoupon.com/users/',
  'dev': 'https://services-dev.dcoupon.com/users/',
  'dcoupon.eu': 'https://services.dcoupon.eu/users/',
  'dcoupon.com': 'https://services.dcoupon.com/users/'
};

class UsersApiHelper {
  static Map<String, dynamic> buildHeaders({
    bool userAuthentication = true,
  }) {
    var headers = <String, dynamic>{};

    final currentDateFormatted = AuthorizationHelper.getCurrentDateFormatted();
    headers[Constants.HEADER_AUTH_METHOD] =
        EnumHelper.enumToString(AuthMethod.SIGNATURE);
    headers[Constants.HEADER_AUTH_TIMESTAMP] = currentDateFormatted;
    headers[Constants.HEADER_AUTH_APIKEY] = ConfigReader.clientApiToken;
    headers[Constants.HEADER_AUTH_SIGNATURE] =
        AuthorizationHelper.getAuthSignature(currentDateFormatted);
    if (userAuthentication) {
      headers[Constants.HEADER_USER_JWT] = ConfigReader.userJwt;
    }

    return headers;
  }

  static String getUserDataUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! + VERSION + "/data";
  }

  static String updateUserDataUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! + VERSION + "/data";
  }

  static String unregisterUserUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! + VERSION + "/unregisterUser";
  }

  static String getLoyaltyAffiliatesUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! +
        VERSION +
        "/loyalty/affiliates/" +
        ConfigReader.clientCountry!;
  }

  static String getUserLoyaltyCardsUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! +
        VERSION +
        "/loyalty/cards";
  }

  static String addOrUpdateLoyaltyCardUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! +
        VERSION +
        "/loyalty/card";
  }

  static String deleteLoyaltyCardUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! +
        VERSION +
        "/loyalty/card";
  }

  static String getUserRedemptionSummaryUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! +
        VERSION +
        "/redemption/summary";
  }

  static String getUserRedemptionHistoryUrl() {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! +
        VERSION +
        "/redemption/history";
  }

  static String getRedemptionDetail(String redemptionId) {
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]! +
        VERSION +
        "/redemption/detail/" +
        redemptionId;
  }
}
